@@ -10,10 +10,10 @@ test_that("Run jskm", {
        ystratalabs = c("Obs", "Lev", "Lev + 5FU"), ystrataname = "rx"), "gtable")
   expect_is(jskm(fit, timeby=500), "gg")
   expect_is(jskm(fit, timeby=500, main = "kaplan", xlabs = "time", ylabs = "Suvrival (%)", surv.scale = "percent"), "gg")
-  expect_is(jskm(fit, pval.size = 7, pval.coord = c(100, 0.2),  pval.testname = T), "gg")
+  expect_is(jskm(fit, pval.size = 7, pval.coord = c(100, 0.2),  pval.testname = T, showpercent = T), "gg")
   expect_is(jskm(fit, timeby=500, ci = T), "gg")
-  expect_is(jskm(fit, timeby=500, legend = F), "gg")
-  expect_is(jskm(fit, timeby=500, cumhaz = T), "gg")
+  expect_is(jskm(fit, timeby=500, legend = F, showpercent = T), "gg")
+  expect_is(jskm(fit, timeby=500, cumhaz = T, cut.landmark = 500, showpercent = T), "gg")
   
   expect_is(jskm(fit, cluster.option = "cluster", cluster.var = "id", pval = T), "gg")
   expect_warning(jskm(fit, cluster.option = "frailty", cluster.var = "id", pval = T))
@@ -45,9 +45,9 @@ test_that("Run svyjskm", {
   expect_error(svyjskm(s2, ci = T))
   s3 <- survey::svykm(Surv(time,status>0)~1, design=dpbc, se = T)
   expect_is(svyjskm(s3, ci = T), "gg")
-  expect_is(svyjskm(s3, ci = F), "gg")
+  expect_is(svyjskm(s3, ci = F, showpercent = T), "gg")
   s4 <- survey::svykm(Surv(time,status>0)~1, design=dpbc, se = F)
   expect_is(svyjskm(s4, ci = F), "gg")
-  expect_error(svyjskm(s4, ci = T))
+  expect_error(svyjskm(s4, ci = T, showpercent = T))
   
 })
